OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Nur sichtbar für Personen, die über die Rufnummernintegration von Talk auf dem Smartphone abgeglichen wurden.",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Nur für Personen dieser Instanz und Gäste sichtbar",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Nur mit vertrauenswürdigen Servern synchronisieren",
    "Published" : "Veröffentlicht",
    "Synchronize to trusted servers and the global and public address book" : "Mit vertrauenswürdigen Servern und dem globalen und öffentlichen Adressbuch synchronisieren",
    "Verify" : "Überprüfen",
    "Verifying …" : "Überprüfe …",
    "Unable to change password" : "Passwort konnte nicht geändert werden",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Akzeptables Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Groups" : "Gruppen",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
    "{actor} added you to group {group}" : "{actor} hat dich zur Gruppe {group} hinzugefügt",
    "You added {user} to group {group}" : "Du hast {user} zur Gruppe {group} hinzugefügt",
    "{actor} added {user} to group {group}" : "{actor} hat {user} zur Gruppe {group} hinzugefügt",
    "An administrator added you to group {group}" : "Ein Administrator hat dich zur Gruppe {group} hinzugefügt",
    "An administrator added {user} to group {group}" : "Ein Administrator hat {user} zur Gruppe {group} hinzugefügt",
    "{actor} removed you from group {group}" : "{actor} hat dich von der Gruppe {group} entfernt",
    "You removed {user} from group {group}" : "Du hast {user} von der Gruppe {group} entfernt",
    "{actor} removed {user} from group {group}" : "{actor} hat {user} von der Gruppe {group} entfernt",
    "An administrator removed you from group {group}" : "Ein Administrator hat dich von der Gruppe {group} entfernt",
    "An administrator removed {user} from group {group}" : "Ein Administrator hat {user} von der Gruppe {group} entfernt",
    "Your <strong>group memberships</strong> were modified" : "Deine <strong>Gruppenmitgliedschaft</strong> wurde geändert",
    "{actor} changed your password" : "{actor} hat dein Passwort geändert",
    "You changed your password" : "Du hast dein Passwort geändert",
    "Your password was reset by an administrator" : "Dein Passwort wurde vom Administrator zurückgesetzt",
    "Your password was reset" : "Dein Passwort wurde zurückgesetzt",
    "{actor} changed your email address" : "{actor} hat deine E-Mail-Adresse geändert",
    "You changed your email address" : "Du hast deine E-Mail-Adresse geändert",
    "Your email address was changed by an administrator" : "Deine E-Mail-Adresse wurde von einem Administrator geändert",
    "You created an app password for a session named \"{token}\"" : "Du hast ein App-Passwort für eine Sitzung mit dem Namen \"{token}\" erstellt.",
    "An administrator created an app password for a session named \"{token}\"" : "Die Administration hat ein App-Passwort für eine Sitzung mit dem Namen \"{token}“ erstellt",
    "You deleted app password \"{token}\"" : "Du hast das App-Passwort \"{token}\" entfernt",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du hast App-Passwort \"{token}\" in \"{newToken}\" umbenannt",
    "You granted filesystem access to app password \"{token}\"" : "Du hast Dateisystemzugriff für App-Passwort \"{token}\" erlaubt",
    "You revoked filesystem access from app password \"{token}\"" : "Du hast Dateisystemzugriff für App-Passwort \"{token}\" widerrufen",
    "Security" : "Sicherheit",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du hast dich erfolgreich mittels Zwei-Faktor-Authentifizierung angemeldet (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ein Anmeldeversuch mittels Zwei-Faktor-Authentifizierung schlug fehl (%1$s)",
    "Remote wipe was started on %1$s" : "Fernlöschung wurde am %1$s gestartet",
    "Remote wipe has finished on %1$s" : "Fernlöschung wurde am %1$s abgeschlossen",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Dein <strong>Passwort</strong> oder deine <strong>E-Mail-Adresse</strong> wurde geändert",
    "Settings" : "Einstellungen",
    "Could not remove app." : "App konnte nicht entfernt werden",
    "Could not update app." : "App konnte nicht aktualisiert werden",
    "Wrong password" : "Falsches Passwort",
    "Unable to change personal password" : "Das persönliche Passwort konnte nicht geändert werden",
    "Saved" : "Gespeichert",
    "Unable to change password. Password too long." : "Passwort konnte nicht geändert werden. Passwort ist zu lang.",
    "Authentication error" : "Authentifizierungsfehler",
    "Wrong admin recovery password. Please check the password and try again." : "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfe das Passwort und versuche es erneut.",
    "Administrator documentation" : "Dokumentation für Administratoren",
    "User documentation" : "Dokumentation für Benutzer",
    "Nextcloud help overview" : "Übersicht über die Nextcloud-Hilfe",
    "Invalid SMTP password." : "Ungültiges SMTP-Passwort",
    "Email setting test" : "Test der E-Mail-Einstellungen",
    "Well done, %s!" : "Gut gemacht, %s!",
    "If you received this email, the email configuration seems to be correct." : "Wenn du diese E-Mail empfangen hast, sind die E-Mail-Einstellungen korrekt.",
    "Email could not be sent. Check your mail server log" : "E-Mail konnte nicht versandt werden. Prüfe dein E-Mail-Server-Protokoll",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Beim Senden der E-Mail ist ein Problem aufgetreten. Bitte überprüfe deine Einstellungen. (Fehler: %s)",
    "Invalid account" : "Ungültiges Benutzerkonto",
    "Invalid mail address" : "Ungültige E-Mail-Adresse",
    "Settings saved" : "Einstellungen gespeichert",
    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
    "Unable to change email address" : "E-Mail-Adresse konnte nicht geändert werden",
    "Unable to set invalid phone number" : "Ungültige Telefonnummer konnte nicht festgelegt werden",
    "Unable to set invalid website" : "Ungültige Webseite konnte nicht eingestellt werden",
    "Some account data was invalid" : "Einige Kontodaten waren ungültig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Um dein X-Konto zu überprüfen, veröffentliche bitte den folgenden Tweet auf X (Bitte stelle sicher, dass der Tweet keinen Zeilenumbruch enthält):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Um deine Webseite zu überprüfen, speichere bitte den folgenden Inhalt im Web-Wurzelverzeichnist in der Datei '.well-known/CloudIdVerificationCode.txt' (bitte stelle sicher, das sich der gesamte Text in einer Zeile befindet):",
    "%1$s changed your password on %2$s." : "%1$s hat dein Passwort auf %2$s geändert.",
    "Your password on %s was changed." : "Dein Passwort auf %s wurde geändert.",
    "Your password on %s was reset by an administrator." : "Dein Passwort auf %s wurde vom Administrator zurückgesetzt.",
    "Your password on %s was reset." : "Dein Passwort auf %s wurde zurückgesetzt",
    "Password for %1$s changed on %2$s" : "Passwort für %1$s geändert auf %2$s",
    "Password changed for %s" : "Passwort geändert für %s",
    "If you did not request this, please contact an administrator." : "Wenn du das nicht angefordert haben solltest, wende dich bitte an den Administrator.",
    "Your email address on %s was changed." : "Deine E-Mail-Adresse auf %s wurde geändert.",
    "Your email address on %s was changed by an administrator." : "Deine E-Mail-Adresse auf %s wurde von einem Administrator geändert.",
    "Email address for %1$s changed on %2$s" : "E-Mail-Adresse für %1$s geändert auf %2$s",
    "Email address changed for %s" : "Die E-Mail-Adresse für %s wurde geändert",
    "The new email address is %s" : "Die neue E-Mail-Adresse lautet %s",
    "Your %s account was created" : "Dein %s-Konto wurde erstellt",
    "Welcome aboard" : "Willkommen an Bord",
    "Welcome aboard %s" : "Willkommen an Bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Willkommen zu deinem %s-Konto. Du kannst deine Daten hinzufügen, schützen und teilen.",
    "Set your password" : "Setze dein Passwort",
    "Go to %s" : "%s aufrufen",
    "Install Client" : "Installiere den Client",
    "Apps" : "Apps",
    "Personal" : "Persönlich",
    "Administration" : "Verwaltung",
    "Users" : "Benutzer",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Artificial Intelligence" : "Künstliche Intelligenz",
    "Administration privileges" : "Administratorrechte",
    "Groupware" : "Groupware",
    "Overview" : "Übersicht",
    "Basic settings" : "Grundeinstellungen",
    "Sharing" : "Teilen",
    "Availability" : "Verfügbarkeit",
    "Calendar" : "Kalender",
    "Personal info" : "Persönliche Informationen",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "E-Mail-Server",
    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
    "Background jobs" : "Hintergrund-Jobs",
    "Unlimited" : "Unbegrenzt",
    "Verifying" : "Überprüfe",
    "Brute-force Throttle" : "Brute-Force-Drosselung",
    "Your remote address could not be determined." : "Ihre Remote-Adresse konnte nicht ermittelt werden.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Ihre Remote-Adresse wurde als \"%s\" erkannt und wird derzeit durch die Brute-Force-Erkennung gedrosselt, was die Leistung verschiedener Anfragen verlangsamt. Wenn die Remote-Adresse nicht Ihre Adresse ist, kann dies ein Hinweis darauf sein, dass ein Proxy nicht richtig konfiguriert ist.",
    "Your remote address \"%s\" is not brute-force throttled." : "Ihre Remote-Adresse \"%s\" ist nicht durch die Brute-Force-Erkennung gedrosselt.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, deinen Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass du es aus dem Document-Root-Verzeichnis des Webservers herausverschiebst.",
    "Database missing columns" : "In der Datenbank fehlen Spalten",
    "Missing optional column \"%s\" in table \"%s\"." : "Fehlende optionale Spalte \"%s\" in der Tabelle \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In der Datenbank fehlen einige optionale Spalten. Da das Hinzufügen von Spalten bei großen Tabellen einige Zeit dauern kann, wurden sie nicht automatisch hinzugefügt, wenn sie optional sein können. Durch Ausführen von \"occ db:add-missing-columns\" können diese fehlenden Spalten manuell hinzugefügt werden, während die Instanz weiter läuft. Sobald die Spalten hinzugefügt sind, könnten einige Funktionen die Reaktionsfähigkeit oder die Benutzerfreundlichkeit verbessern.",
    "Database missing indices" : "In der Datenbank fehlen Indizes",
    "Missing optional index \"%s\" in table \"%s\"." : "Fehlende optionaler Index \"%s\" in der Tabelle \"%s\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In der Datenbank fehlen einige Indizes. Auf Grund der Tatsache, dass das Hinzufügen von Indizes in großen Tabellen einige Zeit in Anspruch nehmen kann, wurden diese nicht automatisch erzeugt. Durch das Ausführen von \"occ db:add-missing-indices\" können die fehlenden Indizes manuell hinzugefügt werden, während die Instanz weiter läuft. Nachdem die Indizes hinzugefügt wurden, sind Anfragen auf die Tabellen normalerweise schneller.",
    "Database missing primary keys" : "In der Datenbank fehlen Primärschlüssel",
    "Missing primary key on table \"%s\"." : "Fehlender Primärschlüssel in Tabelle \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In der Datenbank fehlen einige Primärschlüssel. Aufgrund der Tatsache, dass das Hinzufügen von Primärschlüsseln bei großen Tabellen einige Zeit dauern konnte, wurden sie nicht automatisch hinzugefügt. Durch Ausführen von \"occ db:add-missing-primary-keys\" können diese fehlenden Primärschlüssel manuell hinzugefügt werden, während die Instanz weiter läuft.",
    "Database pending bigint migrations" : "Datenbank mit ausstehenden Bigint-Migrationen",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Bei einigen Spalten in der Datenbank fehlt eine Konvertierung in Big Int. Da die Änderung der Spaltentypen bei großen Tabellen einige Zeit in Anspruch nehmen kann, erfolgt die Änderung nicht automatisch. Durch Ausführen von \"occ db:convert-filecache-bigint“ können diese ausstehenden Änderungen manuell durchgeführt werden. Bei der Durchführung muss die Instanz offline sein.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Diese Instanz wird im Debug-Modus ausgeführt. Aktiviere dies nur für die lokale Entwicklung und nicht in Produktionsumgebungen.",
    "Default phone region" : "Standard-Telefonregion",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Für deine Installation ist keine Standard-Telefonregion festgelegt. Dies ist erforderlich, um Telefonnummern in den Profileinstellungen ohne Ländercode überprüfen zu können. Um Nummern ohne Ländervorwahl zuzulassen, füge bitte „default_phone_region“ mit dem entsprechenden ISO 3166-1-Code der Region zu deiner Konfigurationsdatei hinzu.",
    "Email test" : "E-Mail-Test",
    "Email test was successfully sent" : "Die Test-E-Mail wurde erfolgreich versandt",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du hast deine E-Mail-Serverkonfiguration noch nicht festgelegt oder überprüft. Bitte gehe zu den Grundeinstellungen, um sie einzustellen. Verwende anschließend die Schaltfläche \"E-Mail senden\" unterhalb des Formulars, um deine Einstellungen zu überprüfen.",
    "File locking" : "Dateisperre",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Die transaktionale Dateisperre ist deaktiviert, dies kann zu Problemen mit Race Conditions führen. Aktiviere \"filelocking.enabled\" in config.php, um diese Probleme zu vermeiden.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Die Datenbank wird für transaktionale Dateisperren verwendet. Um die Leistung zu verbessern, konfiguriere bitte Memcache, falls verfügbar.",
    "Forwarded for headers" : "Für Header weitergeleitet",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Ihre \"trusted_proxies“-Einstellungen sind nicht korrekt, es sollte ein Array sein.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Die Konfiguration des Reverse-Proxy-Headers ist falsch. Dies stellt ein Sicherheitsproblem dar und kann es einem Angreifer ermöglichen, seine IP-Adresse so zu fälschen, dass sie für Nextcloud sichtbar ist.",
    "Your IP address was resolved as %s" : "Ihre IP-Adresse wurde aufgelöst als %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Die Konfiguration des Reverse-Proxy-Headers ist falsch oder du greifst über einen vertrauenswürdigen Proxy auf Nextcloud zu. Andernfalls stellt dies ein Sicherheitsproblem dar und kann es einem Angreifer ermöglichen, seine IP-Adresse so zu fälschen, dass sie für Nextcloud sichtbar ist.",
    "Internet connectivity" : "Internetverbindung",
    "Internet connectivity is disabled in configuration file." : "Die Internetverbindung ist in der Konfigurationsdatei deaktiviert.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Dieser Server hat keine funktionierende Internetverbindung: Mehrere Ziele konnten nicht erreicht werden. Dies bedeutet, dass einige Funktionen, wie das Einhängen externer Speicher, Benachrichtigungen über Updates oder die Installation von Drittanbieter-Apps nicht funktionieren. Der Zugriff auf entfernte Dateien und das Senden von E-Mail-Benachrichtigungen wird wahrscheinlich ebenfalls nicht funktionieren. Um alle Funktionen nutzen zu können, stelle bitte eine Internet-Verbindung für diesen Server her.",
    "Old server-side-encryption" : "Alte serverseitige Verschlüsselung",
    "Disabled" : "Deaktiviert",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Das alte serverseitige Verschlüsselungsformat ist aktiviert. Es wird empfohlen, es zu deaktivieren.",
    "Maintenance window start" : "Beginn des Wartungsfensters",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Der Server hat keine konfigurierte Startzeit für das Wartungsfenster. Das bedeutet, dass ressourcenintensive tägliche Hintergrundaufgaben auch während deiner Hauptnutzungszeit ausgeführt werden. Wir empfehlen, das Wartungsfenster auf eine Zeit mit geringer Nutzung festzulegen, damit Benutzer weniger von der Belastung durch diese umfangreichen Aufgaben beeinträchtigt werden.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Wartungsfenster zur Ausführung von umfangreichen Hintergrundaufgaben liegt zwischen {start}:00 UTC und {end}:00 UTC",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Es wurde kein Speichercache konfiguriert. Um die Leistung zu verbessern, konfiguriere bitte Memcache, sofern verfügbar.",
    "Configured" : "Eingerichtet",
    "PHP default charset" : "PHP-Standardzeichensatz",
    "PHP configuration option \"default_charset\" should be UTF-8" : "Die PHP-Konfigurationsoption \"default_charset\" sollte UTF-8 sein",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Die PHP-Funktion \"set_time_limit\" ist nicht verfügbar. Dies kann in angehaltenen Scripten oder einer fehlerhaften Installation resultieren. Es wird dringend empfohlen, diese Funktion zu aktivieren.",
    "Freetype" : "Freetype",
    "Supported" : "Unterstützt",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Dein PHP unterstützt Freetype nicht. Dies wird defekte Profilbilder und eine defekte Anzeige der Einstellungen verursachen.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv(\"PATH\") liefert nur eine leere Antwort zurück.",
    "PHP memory limit" : "PHP-Speicherlimit",
    "The PHP memory limit is below the recommended value of %s." : "Die PHP-Speichergrenze liegt unterhalb des empfohlenen Wertes von %s.",
    "PHP modules" : "PHP-Module",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Dieser Instanz fehlen einige erforderliche PHP-Module. Folgende Module müssen installiert sein:%s .",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Das PHP-OPcache-Modul ist nicht geladen. Für eine bessere Leistung empfiehlt es sich, das Modul in deiner PHP-Installation zu laden.",
    "PHP version" : "PHP-Version",
    "You are currently running PHP %s." : "Du benutzt aktuell PHP %s.",
    "PHP \"output_buffering\" option" : "PHP-Option \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "Die PHP-Konfigurationsoption \"output_buffering“ muss deaktiviert sein",
    "Random generator" : "Zufallsgenerator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP hat keine geeignete Quelle für Zufälligkeit gefunden, wovon aus Sicherheitsgründen dringend abgeraten wird.",
    "Secure" : "Sicher",
    "Configuration file access rights" : "Zugriffsrechte für die Konfigurationsdatei",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Die schreibgeschützte Konfiguration wurde aktiviert. Dies verhindert das Setzen einiger Einstellungen über die Web-Oberfläche. Weiterhin muss bei jedem Update der Schreibzugriff auf die Datei händisch aktiviert werden.",
    "Nextcloud configuration file is writable" : "Die Nextcloud-Konfigurationsdatei ist beschreibbar",
    "Database version" : "Datenbankversion",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützen diese Version nicht und benötigen MariaDB 10.2 oder neuer.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützten diese Version nicht und benötigen MySQL 8.0 oder MariaDB 10.2 oder neuer.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützen diese Version nicht und beötigen PostgreSQL 9.6 oder neuer.",
    "Unknown database platform" : "Unbekannte Datenbankplattform",
    "Architecture" : "Architektur",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Anscheinend verwendest du eine 32-Bit-PHP-Version. Nextcloud benötigt 64-Bit, um gut zu laufen. Bitte aktualisiere dein Betriebssystem und PHP auf 64-Bit!",
    "Database transaction isolation level" : "Isolationsstufe der Datenbanktransaktion",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Deine Datenbank läuft nicht mit der Transaktionsisolationsstufe \"READ COMMITED\". Dies kann Probleme hervorrufen, wenn mehrere Aktionen parallel ausgeführt werden.",
    "Was not able to get transaction isolation level: %s" : "Die Isolationsstufe der Transaktion konnte nicht ermittelt werden: %s",
    "Profile information" : "Profilinformation",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, vollständiger Name, E-Mail-Adresse, Telefonnummer, Adresse, Webseite, X, Organisation, Rolle, Überschrift, Biografie und ob dein Profil aktiviert ist",
    "Nextcloud settings" : "Nextcloud-Einstellungen",
    "Machine translation" : "Maschinelle Übersetzung",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maschinelle Übersetzung kann mittels verschiedener Apps implementiert werden. Hier kannst du die Priorität der von dir aktuell installierten maschinellen Übersetzungs-Apps festlegen.",
    "Speech-To-Text" : "Sprache-zu-Text",
    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Sprache-zu-Text kann mittels verschiedener Apps implementiert werden. Hier kannst du einstellen, welche App verwendet werden soll.",
    "None of your currently installed apps provide Speech-To-Text functionality" : "Keine deiner derzeit installierten Apps bietet Sprache-zu-Text-Funktionalität.",
    "Image generation" : "Bilderstellung",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Die Bilderstellung kann durch verschiedene Apps implementiert werden. Hier kannst du einstellen, welche App verwendet werden soll.",
    "None of your currently installed apps provide image generation functionality" : "Keine deiner derzeit installierten Apps bietet Funktionen zur Bilderstellung.",
    "Text processing" : "Textverarbeitung",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textverarbeitungsaufgaben können mittels verschiedener Apps umgesetzt werden. Hier kannst du einstellen, welche App für welche Aufgabe verwendet werden soll.",
    "Task:" : "Aufgabe:",
    "None of your currently installed apps provide Text processing functionality" : "Keine deiner derzeit installierten Apps bietet Funktionalität zur Textverarbeitung.",
    "Here you can decide which group can access certain sections of the administration settings." : "Hier kannst du festlegen, welche Gruppe auf bestimmte Bereiche der Verwaltungseinstellungen zugreifen kann.",
    "None" : "Keine",
    "Unable to modify setting" : "Einstellung konnte nicht geändert werden",
    "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
    "Allow resharing" : "Weiterverteilen erlauben",
    "Allow sharing with groups" : "Teilen mit Gruppen erlauben",
    "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
    "Allow users to share via link and emails" : "Benutzern erlauben, Inhalte über Links und E-Mails zu teilen",
    "Allow public uploads" : "Öffentliches Hochladen erlauben",
    "Always ask for a password" : "Immer nach einem Passwort fragen",
    "Enforce password protection" : "Passwortschutz erzwingen",
    "Exclude groups from password requirements" : "Gruppen von Passwortanforderungen ausschließen",
    "Exclude groups from creating link shares" : "Gruppen von der Erstellung von Link-Freigaben ausschließen",
    "Groups excluded from sharing" : "Von der Linkfreigabe ausgeschlossene Gruppen",
    "Set default expiration date for shares" : "Lege das Standardablaufdatum für Freigaben fest",
    "Enforce expiration date" : "Ablaufdatum erzwingen",
    "Default expiration time of new shares in days" : "Standardablaufzeit neuer Freigaben in Tagen",
    "Expire shares after x days" : "Freigaben laufen nach x Tagen ab",
    "Set default expiration date for shares to other servers" : "Standardablaufdatum für Freigaben an andere Server festlegen",
    "Enforce expiration date for remote shares" : "Ablaufdatum für Remote-Freigaben erzwingen",
    "Default expiration time of remote shares in days" : "Standardablaufzeit für Remote-Freigaben in Tagen",
    "Expire remote shares after x days" : "Remote-Freigaben laufen nach x Tagen ab",
    "Set default expiration date for shares via link or mail" : "Standardablaufzeit für Link- oder E-Mail-Freigaben festlegen",
    "Default expiration time of shares in days" : "Standardablaufzeit für Freigaben in Tagen",
    "Privacy settings for sharing" : "Datenschutzeinstellungen bezüglich des Teilens",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Die automatische Vervollständigung des Benutzernamens im Freigabedialog und den Zugriff auf das Systemadressbuch erlauben",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Wenn die Autovervollständigung \"gleiche Gruppe\" und \"Rufnummernintegration\" aktiviert ist, reicht eine Übereinstimmung in einem der beiden Bereiche aus, um den Benutzer anzuzeigen.",
    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Benutzern innerhalb derselben Gruppen die automatische Vervollständigung von Benutzernamen erlauben und Systemadressbücher auf Benutzer derselben Gruppen beschränken",
    "Allow username autocompletion to users based on phone number integration" : "Automatische Vervollständigung des Benutzernamens für Benutzer basierend auf der Rufnummernintegration zulassen",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Ermöglicht die automatische Vervollständigung, wenn der vollständigen Namen oder die E-Mail-Adresse eingeben wird (ignoriert fehlende Telefonbuchübereinstimmungen und bei gleicher Gruppenzugehörigkeit)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zeige Haftungsausschluss auf der öffentlichen Upload-Seite (Wird nur gezeigt, wenn die Dateiliste nicht angezeigt wird.) ",
    "Disclaimer text" : "Haftungsausschlusstext",
    "This text will be shown on the public link upload page when the file list is hidden." : "Dieser Text wird auf der öffentlichen Upload-Seite angezeigt wenn die Dateiliste nicht angezeigt wird.",
    "Default share permissions" : "Standardberechtigungen für das Teilen",
    "Changed disclaimer text" : "Geänderter Haftungsausschlusstext",
    "Deleted disclaimer text" : "Haftungsausschlusstext gelöscht",
    "Could not set disclaimer text" : "Haftungsausschlusstext konnte nicht festgelegt werden",
    "Two-Factor Authentication" : "Zwei-Faktor-Authentifizierung",
    "Enforce two-factor authentication" : "Zwei-Faktor-Authentifizierung erzwingen",
    "Limit to groups" : "Auf Gruppen beschränken",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Erzwingen der Zwei-Faktor-Authentifizierung kann nur für bestimmte Gruppen eingestellt werden.",
    "Two-factor authentication is enforced for all members of the following groups." : "Zwei-Faktor-Authentifizierung wird für alle Mitglieder der folgenden Gruppen erzwungen.",
    "Enforced groups" : "Erzwungene Gruppen",
    "Two-factor authentication is not enforced for members of the following groups." : "Zwei-Faktor-Authentifizierung wird für Mitglieder der folgenden Gruppen nicht erzwungen.",
    "Excluded groups" : "Ausgeschlossene Gruppen",
    "Save changes" : "Änderungen speichern",
    "Show details for {appName} app" : "Details für die App {appName} anzeigen",
    "Update to {update}" : "Aktualisieren auf {update}",
    "Remove" : "Entfernen",
    "Disable" : "Deaktivieren",
    "Featured" : "Vorgestellt",
    "This app is supported via your current Nextcloud subscription." : "Diese App wird von deinem aktuellen Nextcloud-Abonnement unterstützt.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
    "All apps are up-to-date." : "Alle Apps sind aktuell.",
    "Icon" : "Symbol",
    "Name" : "Name",
    "Version" : "Version",
    "Level" : "Level",
    "Actions" : "Aktionen",
    "Results from other categories" : "Ergebnisse aus anderen Kategorien",
    "No apps found for your version" : "Es wurden keine Apps für deine Version gefunden",
    "Disable all" : "Alle deaktivieren",
    "Download and enable all" : "Alle herunterladen und aktivieren",
    "_%n app has an update available_::_%n apps have an update available_" : ["Für eine App ist eine Aktualisierung verfügbar.","Für %n Apps sind Aktualisierungen verfügbar."],
    "_Update_::_Update all_" : ["Aktualisieren","Alle aktualisieren"],
    "Nothing to show" : "Nichts anzuzeigen",
    "Loading" : "Lade",
    "Description" : "Beschreibung",
    "Details" : "Details",
    "All" : "Alle",
    "Limit app usage to groups" : "App-Verwendung auf Gruppen beschränken",
    "No results" : "Keine Ergebnisse",
    "Update to {version}" : "Aktualisieren auf {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine untere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine obere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "Author" : "Autor",
    "Categories" : "Kategorien",
    "Resources" : "Ressourcen",
    "Documentation" : "Dokumentation",
    "Interact" : "Interagieren",
    "Report a bug" : "Einen technischen Fehler melden",
    "Request feature" : "Funktion vorschlagen",
    "Ask questions or discuss" : "Fragen stellen oder diskutieren",
    "Rate" : "Bewerten",
    "View in store" : "Im Store anzeigen",
    "Visit website" : "Webseite besuchen",
    "Admin documentation" : "Dokumentation für Administratoren",
    "Developer documentation" : "Dokumentation für Entwickler",
    "Changelog" : "Liste der Veränderungen",
    "Device name" : "Gerätename",
    "Marked for remote wipe" : "Für Fernlöschung markiert",
    "Device settings" : "Geräteeinstellungen",
    "Allow filesystem access" : "Erlaube Dateisystem-Zugriff",
    "Rename" : "Umbenennen",
    "Revoke" : "Widerrufen",
    "Wipe device" : "Gerät löschen",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Zurückziehen dieses Tokens könnte das Löschen von deinem Gerät verhindern, wenn die Löschung noch nicht gestartet wurde.",
    "Google Chrome for Android" : "Google Chrome für Android",
    "{productName} iOS app" : "{productName} iOS-App",
    "{productName} Android app" : "{productName} Android-App",
    "{productName} Talk for iOS" : "{productName} Talk für iOS",
    "{productName} Talk for Android" : "{productName} Talk für Android",
    "This session" : "Diese Sitzung",
    "Device" : "Gerät",
    "Last activity" : "Letzte Aktivität",
    "Devices & sessions" : "Geräte & Sitzungen",
    "Web, desktop and mobile clients currently logged in to your account." : "Aktuell in deinem Konto angemeldete Web-, Desktop- und Mobil-Clients:",
    "App name" : "App-Name",
    "Create new app password" : "Neues App-Passwort erstellen",
    "Error while creating device token" : "Fehler beim Erstellen des Geräte-Tokens",
    "Login" : "Anmelden",
    "Password" : "Passwort",
    "Show QR code for mobile apps" : "QR-Code für mobile Apps anzeigen",
    "Could not copy app password. Please copy it manually." : "Das Passwort für die App konnte nicht kopiert werden. Bitte kopiere es manuell.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Damit der Server ordnungsgemäß funktioniert, ist es wichtig, Hintergrundjobs richtig zu konfigurieren. Cron ist die empfohlene Einstellung. Weitere Informationen findest du in der Dokumentation.",
    "Last job execution ran {time}. Something seems wrong." : "Der letzte Job lief {time}. Etwas scheint falsch zu sein.",
    "Last job ran {relativeTime}." : "Der letzte Job lief {relativeTime}.",
    "Background job did not run yet!" : "Hintergrund-Job wurde bislang nicht ausgeführt!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Empfohlen)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Den System-Cron-Dienst verwenden, um die Datei cron.php alle 5 Minuten aufzurufen.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Die PHP-POSIX-Erweiterung ist erforderlich. Weitere Einzelheiten findest du in der {linkstart}PHP-Dokumentation{linkend}.",
    "Unable to update background job mode" : "Hintergrund-Job-Modus kann nicht aktualisiert werden",
    "Profile" : "Profil",
    "Enable" : "Aktivieren",
    "Unable to update profile default setting" : "Standardeinstellung des Profils kann nicht aktualisiert werden",
    "Server-side encryption" : "Serverseitige Verschlüsselung",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serverseitige Verschlüsselung ermöglicht es, die auf diesen Server hochgeladenen Dateien zu verschlüsseln. Dies führt allerdings auch zu Nachteilen, wie z. B. einem Geschwindigkeitsverlust. Sie sollte deshalb nur eingeschaltet werden, wenn sie wirklich benötigt wird.",
    "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
    "Please read carefully before activating server-side encryption:" : "Bitte lies sorgfältig vor Aktivierung der serverseitigen Verschlüsselung:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung alleine garantiert nicht die Systemsicherheit. Bitte lies in der Dokumentation nach, wie die Verschlüsselungs-app funktioniert und welche Anwendungsfälle unterstützt werden.",
    "Be aware that encryption always increases the file size." : "Bedenke, dass durch die Verschlüsselung die Dateigröße zunimmt. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungen von deinen Daten zu erstellen. Falls du die Verschlüsselung nutzt, sollte auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit deinen Daten durchgeführt werden.",
    "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Möchtest du die Verschlüsselung wirklich aktivieren?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Es wurde kein Verschlüsselungs-Modul geladen, bitte ein Verschlüsselungs-Modul im Anwendungs-Menü aktivieren.",
    "Select default encryption module:" : "Standard-Verschlüsselungs-Modul auswählen:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du musst deine Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) auf die neue migrieren. Bitte aktiviere das \"Standardverschlüsselungsmodul\" und führe {command} aus.",
    "Unable to update server side encryption config" : "Die Serverseitige Verschlüsselungskonfiguration kann nicht aktualisiert werden.",
    "Please confirm the group removal" : "Bitte bestätige die Löschung der Gruppe ",
    "Cancel" : "Abbrechen",
    "Confirm" : "Bestätigen",
    "Submit" : "Übermitteln",
    "Rename group" : "Gruppe umbenennen",
    "Remove group" : "Gruppe entfernen",
    "Failed to remove group \"{group}\"" : "Die Gruppe \"{group}\" konnte nicht entfernt werden.",
    "Current password" : "Aktuelles Passwort",
    "New password" : "Neues Passwort",
    "Change password" : "Passwort ändern",
    "Your profile picture" : "Dein Profilbild",
    "Upload profile picture" : "Profilbild hochladen",
    "Choose profile picture from Files" : "Profilbild aus Dateien wählen",
    "Remove profile picture" : "Profilbild entfernen",
    "The file must be a PNG or JPG" : "Die Datei muss im PNG- oder JPG-Format sein",
    "Picture provided by original account" : "Bild von Original-Konto zur Verfügung gestellt",
    "Set as profile picture" : "Als Profilbild festlegen",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Bitte beachte, dass es bis zu 24 Stunden dauern kann, bis das Profilbild überall aktualisiert wird.",
    "Choose your profile picture" : "Wähle dein Profilbild aus.",
    "Please select a valid png or jpg file" : "Bitte eine gültige PNG- oder JPG-Datei auswählen",
    "Error setting profile picture" : "Fehler beim Einstellen des Profilbilds",
    "Error cropping profile picture" : "Fehler beim Zuschneiden des Profilbilds",
    "Error saving profile picture" : "Fehler beim Speichern des Profilbilds",
    "Error removing profile picture" : "Fehler beim Entfernen des Profilbilds",
    "Your biography" : "Deine Biografie",
    "You are a member of the following groups:" : "Du bist Mitglied folgender Gruppen:",
    "You are using <strong>{usage}</strong>" : "Du benutzt <strong>{usage}</strong>.",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du benutzt <strong>{usage}</strong> von <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>).",
    "Your full name" : "Dein vollständiger Name",
    "Primary email for password reset and notifications" : "Primäre E-Mail-Adresse für Benachrichtigungen und zum Zurücksetzen des Passworts",
    "Email options" : "E-Mail-Optionen",
    "Remove primary email" : "Primäre E-Mail-Adresse entfernen",
    "Delete email" : "E-Mail löschen",
    "This address is not confirmed" : "Diese Adresse ist nicht bestätigt",
    "Unset as primary email" : "Als primäre E-Mail-Adresse deaktivieren",
    "Set as primary email" : "Als primäre E-Mail-Adresse festlegen",
    "Additional email address {index}" : "Zusätzliche E-Mail-Adresse {index}",
    "Unable to delete primary email address" : "Primäre E-Mail-Adresse konnte nicht gelöscht werden",
    "Unable to update primary email address" : "Primäre E-Mail-Adresse konnte nicht aktualisiert werden",
    "Unable to add additional email address" : "Zusätzliche E-Mail-Adresse konnte nicht hinzugefügt werden",
    "Unable to update additional email address" : "Zusätzliche E-Mail-Adresse konnte nicht aktualisiert werden",
    "Unable to delete additional email address" : "Zusätzliche E-Mail-Adresse konnte nicht gelöscht werden",
    "No email address set" : "Keine E-Mail-Adresse angegeben",
    "Your handle" : "Dein Online-Name",
    "Your headline" : "Deine Überschrift",
    "Languages" : "Sprachen",
    "Help translate" : "Hilf bei der Übersetzung mit",
    "Unable to update language" : "Sprache konnte nicht aktualisiert werden",
    "No language set" : "Keine Sprache eingestellt.",
    "Week starts on {firstDayOfWeek}" : "Woche beginnt am {firstDayOfWeek}",
    "Unable to update locale" : "Gebietsschema konnte nicht aktualisiert werden.",
    "No locale set" : "Kein Gebietsschema festgelegt",
    "Your city" : "Deine Stadt",
    "Your organisation" : "Deine Organisation",
    "Your phone number" : "Deine Telefonnummer",
    "Edit your Profile visibility" : "Sichtbarkeit des Profils anpassen",
    "Unable to update profile enabled state" : "Der Status für aktiviertes Profil konnte nicht aktualisiert werden",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Die restriktivere Einstellung von Sichtbarkeit oder Bereich wird in deinem Profil berücksichtigt. Wenn beispielsweise die Sichtbarkeit auf \"Für jeden sichtbar\" und der Bereich auf \"Privat\" festgelegt ist, wird \"Privat\" respektiert.",
    "Unable to update visibility of {displayId}" : "Sichtbarkeit von {displayId} kann nicht aktualisiert werden",
    "Your role" : "Deine Funktion",
    "Your X (formerly Twitter) handle" : "Dein X (früher Twitter)-Handle",
    "Your website" : "Deine Internetseite",
    "No {property} set" : "Keine {property} eingestellt",
    "Unable to update {property}" : "{property} konnte nicht aktualisiert werden.",
    "Change scope level of {property}, current scope is {scope}" : "Ändern des Geltungsbereich von {property}, aktueller Bereich ist {scope}",
    "Unable to update federation scope of the primary {property}" : "Der Federations-Bereich des primären  {property} kann nicht aktualisiert werden.",
    "Unable to update federation scope of additional {property}" : "Der Federations-Bereich des zusätzlichen {property} kann nicht aktualisiert werden.",
    "Add additional email" : "Zusätzliche E-Mail-Adresse hinzufügen",
    "Add" : "Hinzufügen",
    "Create" : "Erstellen",
    "Change" : "Ändern",
    "Delete" : "Löschen",
    "Reshare" : "Weiterteilen",
    "No accounts" : "Keine Konten",
    "Loading accounts …" : "Lade Konten...",
    "Default language" : "Standard-Sprache",
    "Common languages" : "Gängige Sprachen",
    "Other languages" : "Weitere Sprachen",
    "Password change is disabled because the master key is disabled" : "Das Ändern des Passwortes ist deaktiviert, da der Master-Schlüssel deaktiviert ist",
    "New user" : "Neuer Benutzer",
    "Display name" : "Anzeigename",
    "Either password or email is required" : "Passwort oder E-Mail-Adresse ist erforderlich.",
    "Password (required)" : "Passwort (erforderlich)",
    "Email (required)" : "E-Mail-Adresse (erforderlich)",
    "Email" : "E-Mail-Adresse",
    "Groups (required)" : "Gruppen (erforderlich)",
    "Set user groups" : "Benutzergruppen einstellen",
    "Administered groups" : "Administrierte Gruppen",
    "Set user as admin for …" : "Benutzer als Administrator setzen für …",
    "Quota" : "Kontingent",
    "Set user quota" : "Benutzerkontingent einstellen",
    "Language" : "Sprache",
    "Set default language" : "Standard-Sprache einstellen",
    "Manager" : "Manager",
    "Add new user" : "Neuen Benutzer hinzufügen",
    "Set user manager" : "Benutzermanager setzen",
    "Username will be autogenerated" : "Benutzername wird automatisch erzeugt.",
    "Username (required)" : "Benutzername (erforderlich)",
    "Total rows summary" : "Zusammenfassung aller Zeilen",
    "Loading users …" : "Lade Benutzer …",
    "Scroll to load more rows" : "Scrollen, um weitere Zeilen zu laden",
    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} Benutzer …","{userCount} Benutzer …"],
    "_{userCount} user_::_{userCount} users_" : ["{userCount} Benutzer","{userCount} Benutzer"],
    "Avatar" : "Avatar",
    "Username" : "Benutzername",
    "Group admin for" : "Gruppenadministrator für",
    "User backend" : "Benutzer-Backend",
    "Storage location" : "Speicherort",
    "Last login" : "Letzte Anmeldung",
    "User actions" : "Benutzeraktionen",
    "Password or insufficient permissions message" : "Passwort oder unzureichende Berechtigungen Nachricht",
    "Change display name" : "Anzeigename ändern",
    "Set new password" : "Neues Passwort setzen",
    "Set new email address" : "Neue E-Mail-Adresse setzen",
    "Add user to group" : "Benutzer der Gruppe hinzufügen",
    "Set the language" : "Sprache einstellen",
    "{size} used" : "{size} verwendet",
    "Delete account" : "Konto löschen",
    "Resend welcome email" : "Willkommens-E-Mail erneut senden",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Im Falle des Verlusts des Gerätes oder der Verlassens der Organisation können mit dieser Funktion sämtliche Nextcloud-Daten von allen Geräten die mit {userid} verbunden sind gelöscht werden. Funktioniert nur wenn das Gerät mit dem Internet verbunden ist.",
    "Remote wipe of devices" : "Fernlöschung von Geräten",
    "Wipe {userid}'s devices" : "Lösche {userid}s Geräte",
    "Wiped {userid}'s devices" : "{userid}'s Geräte bereinigt",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Vollständig {userid}s Konto löschen inklusive aller persönlichen Dateien, App-Daten, usw.",
    "Account deletion" : "Löschung des Kontos",
    "Delete {userid}'s account" : "Konto von {userid} löschen",
    "Display name was successfully changed" : "Der Anzeigename wurde erfolgreich geändert\n ",
    "Password was successfully changed" : "Das Passwort wurde erfolgreich geändert",
    "Email was successfully changed" : "E-Mail wurde erfolgreich geändert",
    "Welcome mail sent!" : "Willkommens-E-Mail gesendet!",
    "Done" : "Erledigt",
    "Edit" : "Bearbeiten",
    "Visibility" : "Sichtbarkeit",
    "Show language" : "Sprache anzeigen",
    "Show storage path" : "Zeige Speicherpfad",
    "Show last login" : "Letzte Anmeldung anzeigen",
    "Sorting" : "Sortiere",
    "Send email" : "E-Mail senden",
    "Defaults" : "Standardeinstellungen",
    "Default quota" : "Standardkontingent",
    "Select default quota" : "Standardkontingent auswählen",
    "Passwordless authentication requires a secure connection." : "Die Anmeldung ohne Passwort erfordert eine sichere Verbindung.",
    "Add WebAuthn device" : "WebAuthn-Gerät hinzufügen",
    "Please authorize your WebAuthn device." : "Bitte autorisiere dein WebAuthn-Gerät.",
    "Adding your device …" : "Füge dein Gerät hinzu …",
    "Server error while trying to complete WebAuthn device registration" : "Server-Fehler beim Versuch die WebAuthn-Geräte-Registrierung abzuschließen",
    "Unnamed device" : "Unbenanntes Gerät",
    "Passwordless Authentication" : "Authentifizierung ohne Passwort",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Richte dein Konto für die Authentifizierung ohne Passwort nach dem FIDO2-Standard ein.",
    "No devices configured." : "Keine Geräte eingerichtet.",
    "The following devices are configured for your account:" : "Die folgenden Geräte sind für dein Konto eingerichtet:",
    "Your browser does not support WebAuthn." : "Dein Browser unterstützt kein WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als Administrator kannst du das Teilen-Verhalten feinabstimmen. Weitere Informationen findest du in der Dokumentation.",
    "You need to enable the File sharing App." : "Du musst die File sharing App aktivieren.",
    "Admins" : "Administratoren",
    "New account" : "Neues Konto",
    "Create group" : "Gruppe erstellen",
    "Group name" : "Gruppenname",
    "Please enter a valid group name" : "Bitte einen gültigen Gruppennamen eingeben",
    "Failed to create group" : "Fehler beim Erstellen der Gruppe",
    "Sending…" : "Senden …",
    "Email sent" : "E-Mail gesendet",
    "Location" : "Ort",
    "Profile picture" : "Profilbild",
    "About" : "Über",
    "Full name" : "Vollständiger Name",
    "Additional email" : "Zusätzliche E-Mail-Adresse",
    "Headline" : "Überschrift",
    "Organisation" : "Organisation",
    "Phone number" : "Telefonnummer",
    "Role" : "Funktion",
    "X (formerly Twitter)" : "X (früher Twitter)",
    "Fediverse (e.g. Mastodon)" : "Fediverse (wie z. B. Mastodon)",
    "Website" : "Webseite",
    "Profile visibility" : "Sichtbarkeit deines Profils",
    "Locale" : "Gebietsschema",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nicht verfügbar, da diese Eigenschaft für Kernfunktionen wie Dateifreigabe und Kalendereinladungen erforderlich ist.",
    "Your apps" : "Deine Apps",
    "Active apps" : "Aktive Apps",
    "Disabled apps" : "Deaktivierte Apps",
    "Updates" : "Aktualisierungen",
    "App bundles" : "App-Pakete",
    "Featured apps" : "Vorgestellte Apps",
    "Supported apps" : "Unterstützte Apps",
    "Show to everyone" : "Für jeden sichtbar",
    "Hide" : "Ausblenden",
    "Download and enable" : "Herunterladen und aktivieren",
    "Allow untested app" : "Ungetestete App zulassen",
    "The app will be downloaded from the App Store" : "Die App wird aus dem App-Store heruntergeladen",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Diese App ist als nicht-kompatibel mit deiner Nextcloud-Version markiert. Wenn du fortfährst, so kannst du die App installieren. Bitte beachte, dass die App nicht wie erwartet funktionieren könnte.",
    "Never" : "Niemals",
    "An error occurred during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, muss aber aktualisiert werden. Du wirst in 5 Sekunden zur Aktualisierungsseite weitergeleitet.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht. ",
    "Do you really want to wipe your data from this device?" : "Möchtest du wirklich alle Daten von diesem Gerät löschen?",
    "Confirm wipe" : "Löschen bestätigen",
    "Error while wiping the device with the token" : "Fehler während des Löschens des Geräts mit dem Token",
    "Error while updating device token name" : "Fehler bei der Aktualisierung des Geräte-Token-Namens",
    "Error while updating device token scope" : "Fehler bei der Aktualisierung des Geräte-Token-Scope",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zu viele Anfragen aus deinem Netzwerk. Versuche es später erneut oder wende dich an deinen Administrator, wenn dies ein Fehler sein sollte.",
    "Account documentation" : "Kontodokumentation",
    "Administration documentation" : "Administrationsdokumentation",
    "Forum" : "Forum",
    "General documentation" : "Allgemeine Dokumentation",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutzerklärung ",
    "None/STARTTLS" : "Keine/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Dokumentation öffnen",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es ist wichtig, diesen Server so zu konfigurieren, dass E-Mails versandt werden können, z. B. zum Zurücksetzen des Passworts und für Benachrichtigungen.",
    "Send mode" : "Sendemodus",
    "Encryption" : "Verschlüsselung",
    "Sendmail mode" : "Sendmail-Modus",
    "From address" : "Absenderadresse",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Authentication" : "Authentifizierung",
    "Authentication required" : "Authentifizierung benötigt",
    "Credentials" : "Zugangsdaten",
    "SMTP Password" : "SMTP-Passwort",
    "Save" : "Speichern",
    "Test and verify email settings" : "Testen und überprüfen der E-Mail-Einstellungen",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Für die Sicherheit und Performance deiner Instanz ist es wichtig, dass alles richtig konfiguriert ist. Um dir dabei zu helfen, werden einige automatische Prüfungen durchgeführt. Weitere Informationen kannst du der verlinkten Dokumentation entnehmen.",
    "All checks passed." : "Alle Überprüfungen bestanden.",
    "There are some errors regarding your setup." : "Es gibt einige Fehler bei deiner Systemkonfiguration.",
    "There are some warnings regarding your setup." : "Es gibt einige Warnungen bei deiner Systemkonfiguration.",
    "Checking for system and security issues." : "Prüfung auf System- und Sicherheitsprobleme.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bitte überprüfe noch einmal die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">Installationsanleitungen ↗</a> und kontrolliere das <a href=\"%2$s\">Protokoll</a> auf mögliche Fehler oder Warnungen.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Überprüfe die Sicherheit deiner Nextcloud über den <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Sicherheitsscanner der Nextcloud GmbH ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Gründe für die Verwendung von Nextcloud in deiner Organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Entwickelt von der {communityopen}Nextcloud Community{linkclose}, der {githubopen}Quellcode{linkclose} ist lizensiert unter {licenseopen}AGPL{linkclose}-Lizenz.",
    "Like our Facebook page" : "Like uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folge uns auf X",
    "Follow us on Mastodon" : " Folge uns auf Mastodon",
    "Check out our blog" : "Sieh dir unseren Blog an",
    "Subscribe to our newsletter" : "Abonniere unseren Newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Diese Community-Version von Nextcloud wird nicht unterstützt und sofortige Benachrichtigungen sind nicht verfügbar.",
    "Use a second factor besides your password to increase security for your account." : "Verwende neben deinem Passwort einen zweiten Faktor, um die Sicherheit für dein Konto zu erhöhen.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Wenn du Anwendungen von Drittanbietern verwendest, um dich mit Nextcloud zu verbinden, stelle bitte sicher, dass du für jede Anwendung ein Anwendungspasswort erstellst und einrichtest, bevor du die Zwei-Faktor-Authentifizierung aktivierst.",
    "No user supplied" : "Kein Benutzer angegeben",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bitte gib ein Wiederherstellungspasswort für das Administratorkonto an, da sonst alle Benutzerdaten verlorengehen.",
    "Backend does not support password change, but the user's encryption key was updated." : "Das Backend unterstützt die Passwortänderung nicht, aber das Verschlüsselungspasswort des Benutzers wurde aktualisiert",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated-Cloud-Sharing",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL verwendet eine veraltete %1$s Version (%2$s). Bitte aktualisiere dein Betriebssystem, da ansonsten Funktionen, wie z. B. %3$s, nicht zuverlässig funktionieren.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Es konnte nicht festgestellt werden, ob die TLS-Version von cURL veraltet ist oder nicht, da während der HTTPS-Anforderung an https://nextcloud.com ein Fehler aufgetreten ist. Bitte überprüfe die Nextcloud-Protokolldatei für weitere Einzelheiten.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache ist deaktiviert. Für eine bessere Leistung wird empfohlen, <code>opcache.enable=1</code> in deiner PHP-Konfiguration anzuwenden.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache ist so konfiguriert, dass Codekommentare entfernt werden. Wenn OPcache aktiviert ist, muss <code>opcache.save_comments=1</code> gesetzt werden, damit Nextcloud funktioniert.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud darf die OPcache-API nicht verwenden. Wenn OPcache aktiviert ist, wird dringend empfohlen, alle Nextcloud-Verzeichnisse mit <code>opcache.restrict_api</code> einzuschließen oder diese Einstellung zu deaktivieren, um OPcache-API-Einschränkungen zu deaktivieren und Fehler während Nextcloud-Core- oder App-Aktualisierungen zu vermeiden.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud darf die OPcache-API nicht verwenden. Es wird dringend empfohlen, alle Nextcloud-Verzeichnisse mit <code>opcache.restrict_api</code> einzuschließen oder diese Einstellung zu deaktivieren, um OPcache-API-Einschränkungen zu deaktivieren und Fehler während Nextcloud-Core- oder App-Aktualisierungen zu vermeiden.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Der OPcache mit gemeinsamem Speicher ist deaktiviert. Für eine bessere Leistung wird empfohlen, opcache.file_cache_only=0 in Ihre PHP-Konfiguration aufzunehmen und den Dateicache nur als Second Level Cache zu verwenden.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Die maximale Anzahl von OPcache-Schlüsseln ist fast erreicht. Um sicherzustellen, dass alle Skripte im Cache gehalten werden können, wird empfohlen, <code>opcache.max_accelerated_files</code> mit einem höheren Wert als <code>%s</code> in deiner PHP-Konfiguration anzuwenden.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Der OPcache-Puffer ist fast voll. Um sicherzustellen, dass alle Skripte im Cache gehalten werden können, wird empfohlen, <code>opcache.memory_consumption</code> in deiner PHP-Konfiguration mit einem höheren Wert als <code>%s</code> anzuwenden.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Der OPcache-Zwischenspeicher für interne Zeichenfolgen ist fast voll. Um sicherzustellen, dass sich wiederholende Zeichenfolgen effektiv zwischengespeichert werden können, wird empfohlen, <code>opcache.interned_strings_buffer</code> mit einem Wert größer als <code>%s</code> in deiner PHP-Konfiguration anzuwenden.",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Du musst deine Benutzer-E-Mail-Adresse festlegen, bevor du Test-E-Mails senden kannst. Gehe dazu zu %s.",
    "Invalid user" : "Ungültiger Benutzer",
    "Your username is: %s" : "Dein Benutzername lautet: %s",
    "Logged in user must be a subadmin" : "Der angemeldete Benutzer muss ein Administrator sein",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ein Hintergrundjob, der nach vom Benutzer importierten SSL-Zertifikaten sucht, läuft noch. Bitte versuche es später erneut.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Es sind einige vom Benutzer importierte SSL-Zertifikate vorhanden, die von Nextcloud 21 nicht mehr verwendet werden. Du kannst über den Befehl \"occ security:certificates:import\" in der Befehlszeile importiert werden. Ihre Pfade innerhalb des Datenverzeichnisses werden unten angezeigt.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Es wurden ungültige UUIDs von LDAP-Benutzern oder -Gruppen gefunden. Bitte überprüfe deine „UUID-Erkennung überschreiben“-Einstellungen im Expertenteil der LDAP-Konfiguration und verwende „occ ldap:update-uuid“, um sie zu aktualisieren.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occured. Please run it manually by calling occ dav:sync-system-addressbook." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du occ dav:sync-system-addressbook aufrufst.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Zwei-Faktor-Authentifizierung kann für alle Benutzer und Gruppen erzwungen werden. Dann können Benutzer, für die keine Zwei-Faktor-Authentifizierung eingerichtet ist, sich nicht am System anmelden.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Bei der Auswahl/Abwahl von Gruppen wird folgende Logik verwendet, um festzustellen, ob ein Benutzer 2FA verwenden muss: Wenn keine Gruppe ausgewählt ist, dann wird 2FA für alle Benutzer aktiviert, außer für Mitglieder der ausgenommenen Gruppen. Sind Gruppen ausgewählt, so wird 2FA für alle Mitglieder dieser Gruppen aktiviert. Ist ein Benutzer Mitglied der ausgewählten und ausgenommenen Gruppe, so hat die Auswahl Vorrang und 2FA wird aktiviert. ",
    "Enable all" : "Alle aktivieren",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Sync client - {os}" : "Sync-Client - {os}",
    "Error while deleting the token" : "Fehler beim Löschen des Geräte-Tokens",
    "Use the credentials below to configure your app or device." : "Nutze die unten angebenen Anmeldeinformationen, um deine App oder dein Gerät zu konfigurieren.",
    "For security reasons this password will only be shown once." : "Aus Sicherheitsgründen wird das Passwort nur einmal angezeigt.",
    "Copied!" : "Kopiert!",
    "Copy" : "Kopieren",
    "Execute one task with each page loaded. Use case: Single user instance." : "Mit jeder geladenen Seite wird eine Aufgabe ausgeführt. Anwendungsfall: Einzelbenutzer-Installation.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php ist bei einem Webcron-Dienst registriert, um cron.php alle 5 Minuten über HTTP aufzurufen. Anwendungsfall: Sehr kleine Instanz (1–5 Benutzer je nach Nutzung).",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Um dies auszuführen, wird die PHP-Posix Erweiterung benötigt. Weitere Informationen in der {linkstart}PHP-Dokumentation{linkend}. ",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Verwende den System-Cron-Dienst, um die Datei cron.php alle 5 Minuten aufzurufen. Empfohlen für alle Installationen.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Die cron.php muss durch den Systembenutzer \"{user}\" ausgeführt werden.",
    "Enable or disable profile by default for new users." : "Profil für neue Benutzer standardmäßig aktivieren oder deaktivieren",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Du bist dabei die Gruppe {group} zu löschen. Die Benutzer werden NICHT gelöscht.",
    "Please confirm the group removal " : "Bitte die Löschung der Gruppe bestätigen",
    "Your profile information" : "Ihre Profilinformation",
    "Your email address" : "Deine E-Mail-Adresse",
    "Additional emails" : "Zusätzliche E-Mail-Adressen ",
    "Enable Profile" : "Profil aktivieren",
    "Your Twitter handle" : "Dein X-Handle",
    "You do not have permissions to see the details of this user" : "Du hast keine Berechtigung, um auf die Details dieses Benutzers zu sehen",
    "Edit display name" : "Anzeigename bearbeiten",
    "Add new password" : "Neues Passwort hinzufügen",
    "Add new email address" : "Neue E-Mail-Adresse hinzufügen",
    "Set user as admin for" : "Benutzer als Administrator setzen für",
    "Select user quota" : "Kontingent auswählen",
    "Select manager" : "Manager auswählen",
    "Toggle user actions menu" : "Menü für Benutzeraktionen umschalten",
    "Delete user" : "Benutzer löschen",
    "Wipe all devices" : "Alle Geräte löschen",
    "Disable user" : "Benutzer deaktivieren",
    "Enable user" : "Benutzer aktivieren",
    "Edit User" : "Benutzer bearbeiten",
    "User's table" : "Benutzertabelle",
    "Will be autogenerated" : "Wird automatisch erzeugt",
    "Select user manager" : "Benutzermanager wählen",
    "Add a new user" : "Neuen Benutzer hinzufügen",
    "No users in here" : "Keine Benutzer vorhanden",
    "Name your device" : "Gerät benennen",
    "Server error while trying to add WebAuthn device" : "Server-Fehler beim Versuch ein WebAuthn-Gerät hinzuzufügen",
    "{license}-licensed" : "{license}-Lizenziert",
    "by {author}\n{license}" : "von {author}\n{license}",
    "Enter group name" : "Gruppenname eingeben",
    "Add group" : "Gruppe hinzufügen",
    "Active users" : "Aktive Benutzer",
    "Disabled users" : "Deaktivierte Benutzer",
    "Default quota:" : "Standardkontingent:",
    "Show Languages" : "Sprachen anzeigen",
    "Show user backend" : "Benutzer-Backend anzeigen",
    "Send email to new user" : "E-Mail an neuen Benutzer senden",
    "Not saved" : "Nicht gespeichert",
    "Twitter" : "X",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Nicht verfügbar, da Federation für dein Konto deaktiviert ist. Wende dich an deinen Administrator, wenn du Fragen hast.",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nicht verfügbar, da die Veröffentlichung benutzerspezifischer Daten auf dem Lookup-Server nicht zulässig ist. Wende dich bei Fragen an deinen Systemadministrator",
    "Show to logged in users only" : "Nur für angemeldete Benutzer sichtbar",
    "Enable untested app" : "Ungetestete App aktivieren",
    "SMTP Username" : "SMTP-Benutzername",
    "Expire after" : "Ablauf nach",
    "day(s)" : "Tag(en)",
    "Exclude groups from password requirements:" : "Gruppen von Passwortanforderungen ausschließen:",
    "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
    "Exclude groups from creating link shares:" : "Gruppen von der Erstellung von Link-Freigaben ausschließen:",
    "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
    "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
    "Old user imported certificates" : "Alte vom Benutzer importierte Zertifikate",
    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du verwendest derzeit PHP %s. PHP 8.0 ist ab Nextcloud 27 veraltet. Nextcloud 28 erfordert mindestens PHP 8.1. Bitte aktualisiere so schnell wie möglich auf eine der offiziell unterstützten PHP-Versionen der PHP Gruppe.",
    "Rating: {score}/10" : "Bewertung: {score}/10",
    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Du bist dabei die Gruppe \"{group}\" zu löschen. Die Benutzer werden NICHT gelöscht.",
    "No users" : "Keine Benutzer",
    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Liste aller Benutzer. Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Benutzer werden angezeigt, wenn du durch die Liste navigierst.",
    "Loading user …" : "Lade Benutzer …",
    "Failed to update user manager" : "Fehler beim Aktualisieren des Benutzermanagers",
    "User management settings" : "Einstellungen für Benutzerverwaltung",
    "Send welcome email to new users" : "Begrüßungs-E-Mail an neue Benutzer senden",
    "User management" : "Benutzerverwaltung",
    "Creating group …" : "Erstelle Gruppe …",
    "User group: {group}" : "Benutzergruppe: {group}",
    "Nextcloud help resources" : "Nextcloud-Hilferessourcen"
},
"nplurals=2; plural=(n != 1);");
